@@ -1,5 +1,6 @@
 import os
 import re
+import glob
 import logging
 import platform
 import subprocess
@@ -98,9 +99,9 @@ class APP(IDEBase):
         """Search and return a latest armgcc instance from system.
 
         Returns:
-            <armgcc.APP object>
+            <armgcc.APP object> or None
         """
-        path, version = get_armgcc_latest()
+        path, version = find_armgcc_latest()
         if path:
             return APP(path, version=version)
         else:
@@ -131,91 +132,61 @@ class APP(IDEBase):
         return BuildResult.map("pass")
 
 
-    @staticmethod
-    def default_install_path():
-        default_path_table = {
-            "Windows": "C:/Program Files (x86)/GNU Tools ARM Embedded",
-            "Linux": "/usr/local",
-            "Darwin": "/usr/local",
-        }
-        osname = platform.system()
-        return default_path_table[osname]
 
-def _scan_windows_register():
-    try:
-        import _winreg as winreg
-    except ImportError:
-        import winreg
-
-    root_key_path = r"SOFTWARE\\Wow6432Node\\ARM\\GNU Tools for ARM Embedded Processors"
-    try:
-        key_object = winreg.OpenKey(winreg.HKEY_LOCAL_MACHINE, root_key_path)
-        path = winreg.QueryValueEx(key_object, "InstallFolder")[0].replace('\\', '/')
-        version = path.split("/")[-1].replace(" ", "-")
-        winreg.CloseKey(key_object)
-        return path, version
-    except WindowsError:
-        pass
-
-    return None, None
-
-def get_armgcc_latest():
+def find_armgcc_latest():
     """Get the latest armgcc version
 
     Returns:
         tuple -- (path, version)
     """
-    path, version = None, None
-    osname = platform.system()
 
-    if osname == "Windows":
-        path, version = _scan_windows_register()
-        if path:
-            return path, version
+    default_path_table = {
+        "Windows": [
+            "C:/Program Files (x86)/GNU Arm Embedded Toolchain",
+            "C:/Program Files (x86)/GNU Tools ARM Embedded"
+            ],
+        "Linux": ["/usr/local"],
+        "Darwin": ["/usr/local"],
+    }
 
-        logging.debug("Could not found ARM GCC installation in windows register!"\
-        "Trying to scan in default installation directory!")
-
-    root_path = APP.default_install_path()
-    if not os.path.exists(root_path):
-        return None, None
-
-    if osname == "Windows" and not os.path.exists(root_path):
-        root_path = "C:/Program Files/GNU Tools ARM Embedded"
-
-    return get_armgcc_latest_version(root_path)
+    search_paths = default_path_table.get(platform.system())
+    return _find_armgcc_latest_version(search_paths)
 
 
-def get_armgcc_latest_version(rootpath):
+def _find_armgcc_latest_version(search_paths):
     osname = platform.system()
     versions_dict = {}
-    armgcc_rootfolders = []
 
-    if osname == "Windows":
-        armgcc_rootfolders = os.listdir(rootpath)
-    else:
-        try:
-            output = subprocess.check_output(
-                "ls {0} | grep gcc-arm-none-eabi".format(rootpath),
-                shell=True)
-            if not isinstance(output, str):
-                output = output.decode()
-            armgcc_rootfolders = output.split('\n')
-        except subprocess.CalledProcessError:
-            return None, None
-
-    for per_folder in armgcc_rootfolders:
-        if not os.path.isdir(os.path.join(rootpath, per_folder)) or '' == per_folder:
+    for root_path in search_paths:
+        if not os.path.exists(root_path):
             continue
 
-        gcc_exe = os.path.join(rootpath, per_folder, "bin", "arm-none-eabi-gcc")
-        version_content = os.popen("\"{}\" --version".format(gcc_exe)).read()
-        ret = re.search(r"\d\.\d\.\d", version_content)
-        if ret is not None:
-            versions_dict[ret.group()] = os.path.join(rootpath, per_folder)
+        # build the glob serach pattern
+        if osname == "Windows":
+            gcc_exes = glob.glob(root_path + "/*/bin/arm-none-eabi-gcc.exe")
+        else:
+            gcc_exes = glob.glob(root_path + "/gcc-arm-none-eabi*/bin/arm-none-eabi-gcc")
+
+        for gcc_exe in gcc_exes:
+            instance_path = os.path.abspath(os.path.join(gcc_exe, "../../"))
+            if osname == "Windows":
+                version = os.path.basename(instance_path).replace(" ", "-").strip()
+            else:
+                version = os.path.basename(instance_path).replace("gcc-arm-none-eabi-", "")
+
+            # Try to get version from: arm-none-eabi-gcc --version
+            if not version:
+                version_content = os.popen("\"{}\" --version".format(gcc_exe)).read()
+                ret = re.search(r"\d\.\d\.\d", version_content)
+                if ret is not None:
+                    version = ret.group()
+
+            if version:
+                versions_dict[version] = instance_path
 
     if not versions_dict:
         return None, None
 
     latest_v = sorted(versions_dict.keys(), key=lambda v: LooseVersion(v))[-1]
     return versions_dict[latest_v], latest_v
+
