@@ -25,29 +25,25 @@ class RedLink(DebuggerBase):
     Command line flash programming reference:
         https://community.nxp.com/thread/389139
 
-    Notes from MCUXpresso IDE User's Guide:
-        The MCUXpresso IDE Flash programming utility is located at:
-        - crt_emu_cm_redlink.exe is the name of the Flash utility, it is located at
-            <mcuxpressod_root>/ide/bin/.
-        - target is the target chip name. For example LPC1343, LPC1114/301, LPC1768 etc. (see
-        'Finding Correct Parameters...' below)
-        - --flash-load can actually be one of a few different options. Use:
-        - --flash-load to write the file to Flash,
-        - --flash-load-exec to write it to Flash and then cause it to start running,
-        - --flash-mass-load to erase the Flash and then write the file to the Flash, and
-        - --flash-mass-load-exec to erase the Flash, write the file to Flash and then cause it to start running.
-        - filename is the file to Flash program. It may be an executable (axf) or a binary (bin) file. If using
-        a binary file, the base_address also must be specified. Using enclosing quotes is optional
-        unless the name includes unusual characters or spaces.
-        - base_address is the address where the binary file will be written. It can be specified as a hex
-            value with a leading 0x.
-
-        If you are using Flash memory that is external to the main chip you will need to specify an
-        appropriate Flash driver that supports the device. This usually takes the name of a .cfx file held
-        in a default location. In unusual circumstances it is possible to specify an absolute file system
-        name of a file. Using enclosing quotes is optional unless.
     """
+    # Availabe configuration options
+    OPTIONS = [
+        'connectscript',
+        'reset_method',
+        'resetscript',
+        'coreindex',
+        'flash_driver_dir'
+    ]
+
+    # Available methods are:
+    #    system, sysresetreq  - SYSRESETREQ
+    #    core, vectreset - VECTRESET
+    #    soft - software controlled entry into code
+    RESET_METHODS = ("SYSRESETREQ", "VECTRESET", 'soft', 'system', 'core')
+
     def __init__(self, *args, **kwargs):
+        """Constructor method for redlink debugger."""
+
         super(RedLink, self).__init__("redlink", *args, **kwargs)
         self._is_old_version = False
 
@@ -70,6 +66,9 @@ class RedLink(DebuggerBase):
 
         self._crt_emu_redlink = os.path.join(mcux_tool_bin, "crt_emu_cm_redlink.exe").replace("\\", "/")
         self._redlinkserver = os.path.join(mcux_tool_bin, "redlinkserv.exe").replace("\\", "/")
+        if os.name != "nt":
+            self._crt_emu_redlink = self._crt_emu_redlink.replace(".exe", '')
+            self._redlinkserver = self._redlinkserver.replace(".exe", '')
         self.template_root = None
         self.tn = None
         self._redlinkserverpro = None
@@ -152,14 +151,14 @@ class RedLink(DebuggerBase):
 
         return index
 
-    def gen_crt_cmd(self, board, connectscript=None, resetscript=None, device_parts_dir=None, flash_driver_dir="default", coreindex=0):
+    def gen_crt_cmd(self, board, **kwargs):
         """Generate crt_emu_redlink command line string."""
         conf = _parse_conf_from_template(self.template_root)
         conf['connectscript'] = None
 
-        # There is a bug in crt_emu_redlink.exe, when the connscript is set, the client will always use the probeindex 1
-        # if connectscript and os.path.exists(connectscript):
-        #     conf['connectscript'] = connectscript
+        for opt_name, opt_value in kwargs.items():
+            if opt_name in self.OPTIONS and opt_value:
+                conf[opt_name] = opt_value
 
         if conf['devicename']:
             board.devicename = conf['devicename']
@@ -173,13 +172,12 @@ class RedLink(DebuggerBase):
             # "--no-packed",
             # "--reset system,soft",
             # "--flash-driver= ",
-            "-COREINDEX=%s"%coreindex
+            "-COREINDEX=%s" % conf.get('coreindex', 0)
             # "--telnet 3333",
         ]
 
-        # workaround for MIMXRT1052xxxxB, https://jira.sw.nxp.com/browse/RE-1830
-        if board.devicename in ['MIMXRT1052xxxxB', 'MIMXRT1021xxxxx']:
-            _params.append('--reset VECTRESET')
+        if conf.get("reset_method") in self.RESET_METHODS:
+            _params.append('--reset %s' % conf.get("reset_method"))
 
         # self._start_linkserver(connectscript)
 
@@ -195,24 +193,21 @@ class RedLink(DebuggerBase):
             _params.append("--probeserial=%s"%board.usbid)
 
         if conf['connectscript']:
-            _params.append("--connectscript %s"%conf['connectscript'].replace('\\', '/'))
+            _params.append("--connectscript %s" % conf['connectscript'].replace('\\', '/'))
 
         if conf['device_parts_dir']:
             _params.append("-x {}".format(conf['device_parts_dir'].replace('\\', '/')))
 
         # don't use flash driver for RAM and SDRAM
-        if flash_driver_dir is None:
+        if conf.get('flash_driver_dir') is None:
             _params.append("--no-flash-dir-default")
         else:
             # add falsh_dir
-            if flash_driver_dir not in ('default', ''):
-                _params.append("--flash-dir {}".format(flash_driver_dir.replace('\\', '/')))
-            # add falsh_dir from configuration
-            if conf['flash_driver_dir']:
-                _params.append("--flash-dir {}".format(conf['flash_driver_dir'].replace('\\', '/')))
+            if conf.get('flash_driver_dir') not in ('default', ''):
+                _params.append("--flash-dir {}".format(conf.get('flash_driver_dir').replace('\\', '/')))
 
-        if resetscript:
-            _params.append("--resetscript {}".format(resetscript.replace('\\', '/')))
+        if conf.get('resetscript'):
+            _params.append("--resetscript {}".format(conf.get('resetscript').replace('\\', '/')))
 
         return " ".join(_params)
 
@@ -264,8 +259,8 @@ q
 
         def _check_gdb_cmd_run_error(text):
             return 'failed on connect' in text or 'load failed' in text \
-                or "error finishing flash operation" in text \
-                or 'redlink interface error' in text
+                or "error finishing flash operation" in text #\
+                # or 'redlink interface error' in text
 
         gdb_cmd = "{} --exec {} --silent".format(self.gdbpath, filename)
         session = GDBSession.start(gdb_cmd)
@@ -292,7 +287,7 @@ q
 
         return errorcode, session.console_output
 
-    def flash(self, filepath, connectscript=None, resetscript=None, device_parts_dir=None, flash_driver_dir="default", **kwargs):
+    def flash(self, filepath, **kwargs):
         """MCUXPresso IDE crt_emu_cm_redlink utility interface.
 
         This will program image by crt_emu_cm_redlink tool.
@@ -314,13 +309,7 @@ q
         Returns:
             Tuple -- (returncode, output)
         """
-        crt_redlink_cmd = self.gen_crt_cmd(
-            self._board,
-            connectscript,
-            resetscript,
-            device_parts_dir,
-            flash_driver_dir,
-            0)
+        crt_redlink_cmd = self.gen_crt_cmd(self._board, **kwargs)
 
         timeout = kwargs.get("timeout", 300)
         # ret = self._crt_debugging(filepath, crt_redlink_cmd, timeout)
