@@ -13,6 +13,7 @@ from mcutk.apps import appfactory
 from mcutk.sdk_manifest import SDKManifest
 from mcutk.exceptions import ProjectNotFound, ProjectParserError
 
+LOGGER = logging.getLogger(__name__)
 
 TOOLCHAINS = [
     'iar',
@@ -102,10 +103,17 @@ def find_projects(root_dir, recursive=True, include_tools=None, exclude_tools=No
     s_time = time.time()
     sdk_manifest = None
     try:
-        sdk_manifest = SDKManifest.load_from_dir(sdk_root=root_dir)
+        # To speed up the performance, use a workaround to find
+        # the manifest file.
+        if os.path.basename(os.path.abspath(root_dir)) == 'boards':
+            sdk_root = os.path.dirname(os.path.abspath(root_dir))
+        else:
+            sdk_root = root_dir
+        sdk_manifest = SDKManifest.load_from_dir(sdk_root=sdk_root)
+        LOGGER.debug("Found SDK Manifetst: ", sdk_manifest)
         ProjectBase.SDK_MANIFEST = sdk_manifest
     except:
-        pass
+        LOGGER.warning("Not Found SDK Manifetst!")
 
     project = identify_project(root_dir)
     if project:
