@@ -19,8 +19,6 @@ from mcutk import util
 from mcutk.exceptions import ProcessTimeout
 
 
-bin_path = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'bin')
-
 class GitCommandError(Exception):
     pass
 
@@ -82,8 +80,9 @@ class Repo(object):
         """
         self.repo_dir = repo_dir
         self.repo_url = repo_url
+        self.print_git_console = False
         self.occupations = dict()
-        self.try_to_remove_lock = False
+        self.try_to_remove_lock = True
         self.repo_name = repo_url.split("/")[-1].replace(".git", "")
         self.repo_domain = repo_url.replace(self.repo_name+".git", "")
 
@@ -98,7 +97,8 @@ class Repo(object):
             error = None
             logging.info(cmd)
             try:
-                noerror, output = util.run_command(cmd, cwd=cwd, stdout=True, timeout=timeout)
+                stdout = 'capture_print' if self.print_git_console else "capture"
+                noerror, output = util.run_command(cmd, cwd=cwd, stdout=stdout, timeout=timeout)
                 if ignore_errors:
                     return output
 
@@ -163,7 +163,7 @@ class Repo(object):
         if not repo_dir:
             repo_dir = self.repo_dir
 
-        return self.__exec("git log -n 1", cwd=repo_dir, timeout=1)
+        return self.__exec("git log -n 1", cwd=repo_dir, timeout=10)
 
     def get_branch_name(self, repo_dir=None):
         """Return branch name.
@@ -172,7 +172,7 @@ class Repo(object):
         """
         if not repo_dir:
             repo_dir = self.repo_dir
-        return self.__exec("git rev-parse --abbrev-ref HEAD", cwd=repo_dir, timeout=2, ignore_errors=True).replace("\n", "").strip()
+        return self.__exec("git rev-parse --abbrev-ref HEAD", cwd=repo_dir, timeout=10, ignore_errors=True).replace("\n", "").strip()
 
     def get_submodules(self, repo_dir=None):
         """Return a dictionary about all submodules.
@@ -230,7 +230,7 @@ class Repo(object):
 
     def get_head_hash(self):
         """Return commit hash from head."""
-        return self.__exec("git rev-parse HEAD", timeout=1, ignore_errors=True).replace("\n", "").strip()
+        return self.__exec("git rev-parse HEAD", timeout=10, ignore_errors=True).replace("\n", "").strip()
 
     def get_history_abbrev(self, since="1.weeks"):
         """Useful options for git log --pretty=format
